/testing/guestbin/swan-prep
ipsec start
../../guestbin/wait-until-pluto-started
ipsec auto --add westnet-eastnet-esp-null-alg
ipsec auto --status
echo "initdone"
